@@ -2,7 +2,6 @@ from __future__ import division
 from __future__ import print_function
 
 import argparse
-import genericpath
 import json
 import netrc
 import ntpath
@@ -20,42 +19,22 @@ from os.path import dirname
 from os.path import exists
 from os.path import join
 from os.path import split
+from subprocess import CalledProcessError
+from subprocess import check_output
+from urllib.parse import parse_qs
+from urllib.parse import urlparse
 
-from .compat import PY3
-from .compat import PY38
+import genericpath
+
+from .compat import PY38, PY311
 
 # This is here (in the utils module) because it might be used by
 # various other modules.
 try:
-    from pathlib2 import Path   # noqa: F401
+    from pathlib2 import Path  # noqa: F401
 except ImportError:
-    from pathlib import Path    # noqa: F401
+    from pathlib import Path  # noqa: F401
 
-try:
-    from urllib.parse import urlparse, parse_qs
-except ImportError:
-    from urlparse import urlparse, parse_qs
-
-try:
-    from subprocess import check_output, CalledProcessError
-except ImportError:
-    class CalledProcessError(subprocess.CalledProcessError):
-        def __init__(self, returncode, cmd, output=None):
-            super(CalledProcessError, self).__init__(returncode, cmd)
-            self.output = output
-
-    def check_output(*popenargs, **kwargs):
-        if 'stdout' in kwargs:
-            raise ValueError('stdout argument not allowed, it will be overridden.')
-        process = subprocess.Popen(stdout=subprocess.PIPE, *popenargs, **kwargs)
-        output, unused_err = process.communicate()
-        retcode = process.poll()
-        if retcode:
-            cmd = kwargs.get("args")
-            if cmd is None:
-                cmd = popenargs[0]
-            raise CalledProcessError(retcode, cmd, output)
-        return output
 
 TIME_UNITS = {
     "": "Seconds",
@@ -251,12 +230,8 @@ def load_timer(string):
         raise argparse.ArgumentTypeError("Value for --benchmark-timer must be in dotted form. Eg: 'module.attr'.")
     mod, attr = string.rsplit(".", 1)
     if mod == 'pep418':
-        if PY3:
-            import time
-            return NameWrapper(getattr(time, attr))
-        else:
-            from . import pep418
-            return NameWrapper(getattr(pep418, attr))
+        import time
+        return NameWrapper(getattr(time, attr))
     else:
         __import__(mod)
         mod = sys.modules[mod]
@@ -468,6 +443,7 @@ def load_storage(storage, **kwargs):
         return FileStorage(storage[len("file://"):], **kwargs)
     elif storage.startswith("elasticsearch+"):
         from .storage.elasticsearch import ElasticsearchStorage
+
         # TODO update benchmark_autosave
         args = parse_elasticsearch_storage(storage[len("elasticsearch+"):],
                                            netrc_file=netrc_file)
@@ -540,13 +516,15 @@ def clonefunc(f):
     if not hasattr(f, '__code__'):
         return f
     co = f.__code__
-    args = [co.co_argcount, co.co_nlocals, co.co_stacksize, co.co_flags, co.co_code,
+    args = [co.co_argcount, co.co_kwonlyargcount, co.co_nlocals, co.co_stacksize, co.co_flags, co.co_code,
             co.co_consts, co.co_names, co.co_varnames, co.co_filename, co.co_name,
             co.co_firstlineno, co.co_lnotab, co.co_freevars, co.co_cellvars]
     if PY38:
         args.insert(1, co.co_posonlyargcount)
-    if PY3:
-        args.insert(1, co.co_kwonlyargcount)
+
+    if PY311:
+        args.insert(12, co.co_qualname)
+        args.insert(15, co.co_exceptiontable)
     co2 = types.CodeType(*args)
     #
     # then, we clone the function itself, using the new co2
@@ -584,6 +562,10 @@ def report_noprogress(iterable, *args, **kwargs):
         yield "", item
 
 
+def report_online_progress(progress_reporter, tr, line):
+    next(progress_reporter([line], tr, "{value}"))
+
+
 def slugify(name):
     for c in r"\/:*?<>| ":
         name = name.replace(c, '_').replace('__', '_')
